summaryrefslogtreecommitdiff
path: root/comsat/action.c
diff options
context:
space:
mode:
authorSergey Poznyakoff <gray@gnu.org.ua>2006-09-27 16:10:54 +0000
committerSergey Poznyakoff <gray@gnu.org.ua>2006-09-27 16:10:54 +0000
commit282d86366cfc3eb2885efd31b24b1845339e13be (patch)
treede71f347080bfdde07d8c7581f7f0fd893683d70 /comsat/action.c
parentdf97d9778ab4586c7c9ce234fcf07ae743e5392b (diff)
downloadmailutils-282d86366cfc3eb2885efd31b24b1845339e13be.tar.gz
mailutils-282d86366cfc3eb2885efd31b24b1845339e13be.tar.bz2
Minor fixes
Diffstat (limited to 'comsat/action.c')
-rw-r--r--comsat/action.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/comsat/action.c b/comsat/action.c
index 2ba13db80..e4bbf0896 100644
--- a/comsat/action.c
+++ b/comsat/action.c
@@ -26,7 +26,7 @@
are executed in sequence. Possible actions:
beep -- Produce audible signal
- echo STRING -- Output STRING to the user's tty
+ echo ARGS... -- Output ARGS to the user's tty
exec PROG ARGS... -- Execute given program (absolute pathname
required)
@@ -36,7 +36,7 @@
$h -- Expands to hostname
$H{name} -- Expands to value of message header `name'
$B(C,L) -- Expands to message body. C and L give maximum
- number of characters and line in the expansion.
+ number of characters and lines in the expansion.
When omitted, they default to 400, 5. */
static unsigned

Return to:

Send suggestions and report system problems to the System administrator.